import asyncio

from kutana import Environment

from test_framework import KutanaTest


class TestEnvironments(KutanaTest):
    def test_replace_method(self):
        messages = []

        async def save(self, message):
            messages.append(message)

        env = Environment(None)
        env.replace_method("reply", save)

        asyncio.get_event_loop().run_until_complete(
            env.reply("message")
        )

        self.assertEqual(messages, ["message"])

    def test_spawn(self):
        env = Environment("manager")
        inner_env = env.spawn()

        self.assertEqual(env.manager, inner_env.manager)
        self.assertEqual(env.parent, None)
        self.assertEqual(inner_env.parent, env)



"""
Manager, environment and utils for interacting with Telegram.

Example "configuration.json" for TGManager ("tg_proxy" is optional):

.. code-block:: json

    {
        "tg_token": "API TOKEN",
        "tg_proxy": "http://address_of_prox:port"
    }

Example of initializating TGManager:

.. code-block:: python

    manager2 = TGManager(
        load_value("tg_token", "configuration.json"),
        load_value("tg_proxy", "configuration.json"),
    )

.. note::
    - Attachmnet type "document" is replaced with "doc" inside of engine.
    - Files and photos can't be uploaded without "send_message" or "replay".

"""

from .manager import TGManager, TGResponse
from .environment import TGEnvironment
